summaryrefslogtreecommitdiffstats
path: root/test/vfd_swmr_dsetchks_writer.c
diff options
context:
space:
mode:
authorvchoi <vchoi@jelly.ad.hdfgroup.org>2021-06-29 18:15:28 (GMT)
committervchoi <vchoi@jelly.ad.hdfgroup.org>2021-06-29 18:15:28 (GMT)
commita396a18d40c3b400a0c69e178fd7c2745b831c74 (patch)
tree80ef43bb2d4907471c4642962c234123da6544d6 /test/vfd_swmr_dsetchks_writer.c
parent63db18aa6515e0a37ba6b0312605a397d0226652 (diff)
downloadhdf5-a396a18d40c3b400a0c69e178fd7c2745b831c74.zip
hdf5-a396a18d40c3b400a0c69e178fd7c2745b831c74.tar.gz
hdf5-a396a18d40c3b400a0c69e178fd7c2745b831c74.tar.bz2
Modifications based on PR feedback.
Diffstat (limited to 'test/vfd_swmr_dsetchks_writer.c')
-rw-r--r--test/vfd_swmr_dsetchks_writer.c31
1 files changed, 18 insertions, 13 deletions
diff --git a/test/vfd_swmr_dsetchks_writer.c b/test/vfd_swmr_dsetchks_writer.c
index 47802c4..25066d8 100644
--- a/test/vfd_swmr_dsetchks_writer.c
+++ b/test/vfd_swmr_dsetchks_writer.c
@@ -20,7 +20,7 @@
* 4. extensible array (1 unlimited max_dims, default incremental allocation)
* 5. btree2 (2 unlimited max_dims, default incremental allocation)
*
- * --with compression--H5Pset_shuffle(dcpl)
+ * --with compression--H5Pset_deflate(dcpl)
* --with fill values--H5Pset_fill_value(dcpl, H5T_NATIVE_INT, &fillval);
*
* Types of chunk operations:
@@ -223,7 +223,7 @@ usage(const char *progname)
"-q: silence printouts, few messages\n"
"-b: write data in big-endian byte order\n"
" (default is H5T_NATIVE_UINT32)\n\n"
- "-o: enable compression (shuffle filter) for the datasets\n");
+ "-o: enable compression (deflate filter) for the datasets\n");
fprintf(
stderr,
@@ -447,7 +447,7 @@ error:
* --2-dimensional chunked datasets
* --chunk dimension is rows/2 by cols/2
* --fill value is FILL_INIT
* --shuffle filter if specified
* --dataset with single index if specified
* --dataset with implicit index if specified
* --dataset with fixeda array index if specified
@@ -490,8 +490,8 @@ create_dsets(const state_t *s, dsets_state_t *ds)
/* Set to use filter as specified */
if (s->use_filter) {
- if (H5Pset_shuffle(dcpl) < 0) {
- printf("H5Pset_shuffle failed\n");
+ if (H5Pset_deflate(dcpl, 5) < 0) {
+ printf("H5Pset_deflate failed\n");
goto error;
}
}
@@ -1655,14 +1655,9 @@ verify_dsets_chunks(unsigned action, const state_t *s, const dsets_state_t *ds,
}
}
- if (vbuf)
- HDfree(vbuf);
-
return true;
error:
- if (vbuf)
- HDfree(vbuf);
return false;
@@ -1739,6 +1734,11 @@ verify_read_dset(unsigned action, hid_t did, hid_t tid, hsize_t *start, hsize_t
TEST_ERROR;
}
+ if (H5Sclose(mem_sid) < 0) {
+ printf("H5Sclose failed\n");
+ TEST_ERROR;
+ }
+
if (rbuf)
HDfree(rbuf);
@@ -1851,6 +1851,11 @@ verify_dset_extent_real(unsigned action, hid_t did, unsigned rows, unsigned cols
} /* end switch */
+ if (H5Sclose(sid) < 0) {
+ printf("H5Sclose failed\n");
+ TEST_ERROR;
+ }
+
return true;
error:
@@ -2134,11 +2139,11 @@ main(int argc, char **argv)
TEST_ERROR;
}
- personality = strstr(s.progname, "vfd_swmr_dsetchks_");
+ personality = HDstrstr(s.progname, "vfd_swmr_dsetchks_");
- if (personality != NULL && strcmp(personality, "vfd_swmr_dsetchks_writer") == 0)
+ if (personality != NULL && HDstrcmp(personality, "vfd_swmr_dsetchks_writer") == 0)
writer = true;
- else if (personality != NULL && strcmp(personality, "vfd_swmr_dsetchks_reader") == 0)
+ else if (personality != NULL && HDstrcmp(personality, "vfd_swmr_dsetchks_reader") == 0)
writer = false;
else {
printf("unknown personality, expected vfd_swmr_dsetchks_{reader,writer}\n");
@@ -447,7 +447,7 @@ error:
* --chunk dimension is rows/2 by cols/2
* --fill value is FILL_INIT
- * --shuffle filter if specified
+ * --deflate filter if specified
* --dataset with single index if specified
* --dataset with implicit index if specified